@@ -1,7 +1,7 @@
 from . import config
 from . import connector
-from . import devices
 from . import encoder
 from . import executor
+from . import killer
 from . import logging
 from . import worker
